==> navigine_sdk-1.2.1.tar.gz: lib/controllers/navigation.dart <==
part of navigine_sdk;

class NavigationThread {
  StreamController<DeviceInfo>? controller;

  static Future<NavigationThread> startNavigation({
    NavigationMode mode = NavigationMode.MODE_NORMAL,
  }) async {
    await _channel.invokeMethod("startNavigation", {
      "mode": _getModeCode(mode),
    });
    return NavigationThread();
  }

  stopNavigation() async {
    await _channel.invokeMethod("stopNavigation");
  }

  Future<void> addTarget(LocationPoint point) async {
    await _channel.invokeMethod(
      "addTarget",
      {"locationPoint": point.toMap()},
    );
  }

  Future<void> cancelTarget() async {
    await _channel.invokeMethod("cancelTarget");
  }

  Future<RoutePath> makeRoute(
    LocationPoint point1,
    LocationPoint point2,
  ) async {
    return RoutePath.fromMap(
      await _channel.invokeMethod(
        "makeRoute",
        {
          "locationPoint1": point1.toMap(),
          "locationPoint2": point2.toMap(),
        },
      ),
    );
  }

  Stream<DeviceInfo> getDeviceInfoListener() {
    controller = StreamController<DeviceInfo>();
    _channel.setMethodCallHandler((call) async {
      switch (call.method) {
        case "deviceInfo#onUpdate":
          controller!.add(DeviceInfo.fromMap(call.arguments));
          break;
        default:
      }
    });
    controller!.onCancel = () async {
      await _channel.invokeMethod("stopNavigation");
      controller!.close();
    };
    return controller!.stream;
  }

  Future<DeviceInfo> getDeviceInfo() async {
    return DeviceInfo.fromMap(await _channel.invokeMethod("getDeviceInfo"));
  }

  static _getModeCode(NavigationMode mode) {
    switch (mode) {
      case NavigationMode.MODE_IDLE:
        return 1;
      case NavigationMode.MODE_SCAN:
        return 2;
      case NavigationMode.MODE_NORMAL:
        return 3;
      case NavigationMode.MODE_ECONOMIC:
        return 4;
      default:
    }
  }
}

enum NavigationMode {
  MODE_IDLE,
  MODE_SCAN,
  MODE_NORMAL,
  MODE_ECONOMIC,
}

==> navigine_sdk-1.2.2.tar.gz: lib/controllers/navigation.dart <==
part of navigine_sdk;

class NavigationThread {
  StreamController<DeviceInfo>? controller;

  static Future<NavigationThread> startNavigation({
    NavigationMode mode = NavigationMode.MODE_NORMAL,
  }) async {
    await _channel.invokeMethod("startNavigation", {
      "mode": _getModeCode(mode),
    });
    return NavigationThread();
  }

  stopNavigation() async {
    await _channel.invokeMethod("stopNavigation");
  }

  Future<void> addTarget(LocationPoint point) async {
    await _channel.invokeMethod(
      "addTarget",
      {"locationPoint": point.toMap()},
    );
  }

  Future<void> cancelTarget() async {
    await _channel.invokeMethod("cancelTarget");
  }

  Future<RoutePath> makeRoute(
    LocationPoint point1,
    LocationPoint point2,
  ) async {
    return RoutePath.fromMap(
      await _channel.invokeMethod(
        "makeRoute",
        {
          "locationPoint1": point1.toMap(),
          "locationPoint2": point2.toMap(),
        },
      ),
    );
  }

  StreamController<NavigineNotification>? _controller;

  Stream<NavigineNotification> notificationStream() {
    _controller = StreamController();
    _channel.invokeMethod('attachNotificationListener');
    _controller!.onCancel = () async {
      await _channel.invokeMethod('removeNotificationListener');
      _controller?.close();
      _controller = null;
    };

    return _controller!.stream;
  }

  Stream<DeviceInfo> getDeviceInfoListener() {
    controller = StreamController<DeviceInfo>();
    _channel.setMethodCallHandler((call) async {
      switch (call.method) {
        case "deviceInfo#onUpdate":
          controller?.add(DeviceInfo.fromMap(call.arguments));
          break;
        case "marketing#onNotification":
          _controller?.add(NavigineNotification.fromMap(call.arguments));
          break;
        default:
      }
    });
    controller!.onCancel = () async {
      await _channel.invokeMethod("stopNavigation");
      controller!.close();
      controller = null;
    };
    return controller!.stream;
  }

  Future<DeviceInfo> getDeviceInfo() async {
    return DeviceInfo.fromMap(await _channel.invokeMethod("getDeviceInfo"));
  }

  static _getModeCode(NavigationMode mode) {
    switch (mode) {
      case NavigationMode.MODE_IDLE:
        return 1;
      case NavigationMode.MODE_SCAN:
        return 2;
      case NavigationMode.MODE_NORMAL:
        return 3;
      case NavigationMode.MODE_ECONOMIC:
        return 4;
      default:
    }
  }
}

enum NavigationMode {
  MODE_IDLE,
  MODE_SCAN,
  MODE_NORMAL,
  MODE_ECONOMIC,
}
